@@ -1,4 +1,4 @@
 # __init__.py
-__all__ = ["vms", "icon"]
+from .vms import *
 # Version of the realpython-reader package
-__version__ = "0.1.2"
+__version__ = "0.1.3"
